@@ -46,6 +46,7 @@ void  get_curset(CurrencyWidget **p) {
 
         (*p)->curset->name  = NULL;
         (*p)->curset->active_currency = NULL;
+        (*p)->curset->inc_dec_status = 0;
 
 }
 
@@ -78,6 +79,7 @@ void init_currency(currency **cur) {
                 fprintf(stderr, "Memory could not be allocated!");
                 exit(EXIT_FAILURE);
         }
+        (*cur)->numerical_value = 0;
 }
 
 
