@@ -43,6 +43,12 @@ static GtkWidget *update_ui(CurrencyWidget *plug) {
     if (  plug->curset->not_updated == 1 ) {
         sprintf(tmp_string, "%s = <span fgcolor='#E47833'>%s </span>%s", plug->curset->active_currency->name, plug->curset->active_currency->value, plug->curset->name);
     }
+    else if ( plug->curset->inc_dec_status == 1 ) {
+        sprintf(tmp_string, "%s = <span fgcolor='#00ff00'>%s </span>%s", plug->curset->active_currency->name, plug->curset->active_currency->value, plug->curset->name);
+    }
+    else if ( plug->curset->inc_dec_status == -1) {
+        sprintf(tmp_string, "%s = <span fgcolor='#ff0000'>%s </span>%s", plug->curset->active_currency->name, plug->curset->active_currency->value, plug->curset->name);
+    }
     else {
         sprintf(tmp_string, "%s = %s %s", plug->curset->active_currency->name, plug->curset->active_currency->value , plug->curset->name);
     }
@@ -54,6 +60,7 @@ static GtkWidget *update_ui(CurrencyWidget *plug) {
         gtk_widget_destroy(plug->curr_flag);
     }
     plug->curr_flag = gtk_image_new_from_file (plug->curset->active_currency->icon);
+//    plug->curr_flag = gtk_image_new_from_stock(currencies[plug->curset->active_currency->type - 1], GTK_ICON_SIZE_BUTTON);
     gtk_container_add(GTK_CONTAINER(plug->curr_box), plug->curr_flag);
     gtk_box_reorder_child (GTK_BOX(plug->curr_box), GTK_WIDGET(plug->curr_flag), 0);
 
@@ -152,10 +159,14 @@ callback( GtkWidget *widget,   GdkEventButton* event, CurrencyWidget *desktop_pl
     else {
         sprintf(tmp, "%s%d minutes ago", tmp,minutes % 60);
     }
-
         
-        
-    dialog = gtk_dialog_new_with_buttons(tmp, NULL, (GtkDialogFlags)0, "About", GTK_RESPONSE_ABOUT, dgettext("hildon-libs", "wdgt_bd_done"), GTK_RESPONSE_ACCEPT,  NULL);
+    dialog = gtk_dialog_new_with_buttons(
+	tmp, NULL, (GtkDialogFlags)0,	
+	// actions:
+	"About", GTK_RESPONSE_ABOUT, // About
+	"Donate", GTK_RESPONSE_DONATE, // Donate
+	dgettext("hildon-libs", "wdgt_bd_done"), GTK_RESPONSE_ACCEPT,
+	NULL);
     gtk_window_set_default_size(GTK_WINDOW(dialog), -1, 230);
 
     /* Create tree model */
@@ -171,6 +182,11 @@ callback( GtkWidget *widget,   GdkEventButton* event, CurrencyWidget *desktop_pl
     GtkWidget *content = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
 
 
+    GtkWidget *check_button = hildon_check_button_new ( HILDON_SIZE_FINGER_HEIGHT );
+    gtk_button_set_label(GTK_BUTTON(check_button), "Change all the reference currencies");
+
+    // the check box will be added in the end.
+    // gtk_box_pack_start(GTK_BOX(pan_content), check_button, FALSE, FALSE, 0);
 
     // Create selectors 
     for ( j = 0; j  < 2 ; j++ ) {
@@ -278,7 +294,8 @@ callback( GtkWidget *widget,   GdkEventButton* event, CurrencyWidget *desktop_pl
     }
 
     gtk_box_pack_start(GTK_BOX(pan_content), button[4], FALSE, FALSE, 0);
-
+    // No check box in the end!!! It causes crash report.
+    // gtk_box_pack_start(GTK_BOX(pan_content),check_button, FALSE, FALSE, 0);
 
     hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pan), pan_content);
     gtk_container_add(GTK_CONTAINER(content), pan); 
@@ -366,6 +383,24 @@ callback( GtkWidget *widget,   GdkEventButton* event, CurrencyWidget *desktop_pl
                     exit(EXIT_FAILURE);
                     break;
             }
+            if ( hildon_check_button_get_active ( check_button ) ) {
+                printf("sending message\n\n");
+                fflush(stdout);
+                DBusMessage *message;
+                
+                dbus_int32_t new_value =  desktop_plugin->curset->type;
+
+                message = dbus_message_new_signal ( "/com/binop/dbus/Change", "com.binop.currencyexchangewidget.refcursignal.Signal", "Changed");
+                printf("created signal\n\n");
+                fflush(stdout);
+                dbus_message_append_args(message, DBUS_TYPE_INT32, &new_value, DBUS_TYPE_INVALID);
+                printf("appended args\n\n");
+                fflush(stdout);
+                dbus_connection_send ( desktop_plugin->bus, message, NULL);
+                printf("message sent\n\n");
+                fflush(stdout);
+                dbus_message_unref(message);
+            }
             pthread_mutex_unlock(&desktop_plugin->mutex);
 
             g_timeout_add(100,as_update_values_once,desktop_plugin);
@@ -376,8 +411,12 @@ callback( GtkWidget *widget,   GdkEventButton* event, CurrencyWidget *desktop_pl
         else if ( result == GTK_RESPONSE_ABOUT ) {
             about_dialog();
         }
+        else if ( result == GTK_RESPONSE_DONATE ) {
+            fire_web_browser();
+            gtk_widget_destroy(dialog);
+            break;
+        }
         else {
-
             gtk_widget_destroy(dialog);
             break;
         }
@@ -515,8 +554,7 @@ void about_dialog() {
     gtk_text_buffer_insert_pixbuf (GTK_TEXT_BUFFER(text_buffer), &iter, pixbuf);
 
     char tmp_text[1000];
-    sprintf(tmp_text, "\n\nCurrency Exchange Widget version 0.1.3\n\nCurrency Exchange Widget displays the current exchange rate\nof the selected currency.\n\nThis software is released under the GPL license.\n\nSource of exchange rate data: www.xurrency.com\nSource of flag icons: www.icondrawer.com\n\nwww.binop.com\n2010 %lc binop consulting group\n", 0xa9 );
-
+    sprintf(tmp_text, "\n\nCurrency Exchange Widget version 0.1.5\n\nCurrency Exchange Widget displays the exchange rates of any pair\nof currencies.\n\nMultiple widgets can be added, so it is possible to\nsimultaneously track as many exchange rates as you want.\n\nExchange rates are automatically updated from the Internet.\n\nThis software is released under the GPL license.\n\nSource of exchange rate data: www.xurrency.com\nSource of flag icons: www.icondrawer.com\n\nwww.binop.com\n2010 %lc binop consulting group\n", 0xa9 );
 
     gtk_text_buffer_insert(text_buffer, &iter, tmp_text, -1);
 
@@ -527,3 +565,7 @@ void about_dialog() {
     gtk_widget_destroy(dialog);
 }
 
+
+void fire_web_browser() {
+  system("dbus-send --system --type=method_call --dest=\"com.nokia.osso_browser\" --print-reply /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=LQNV5876M5T42&lc=US&item_name=binop%20consulting%20group&item_number=CurrencyExchangeWidget&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted\"");
+}
