@@ -23,6 +23,7 @@
 #include <string.h>
 #include "cJSON.h"
 #include "lib-currency-home-widget.h"
+#include <math.h>
 
 extern char * get_html(char *url);
 extern char *currencies[];
@@ -69,8 +70,21 @@ void get_values_json(CurrencyWidget **p) {
         char st[20];
         snprintf(st,7,"%lf",value);
         st[7] = '\0'; 
+
+        
+        if ( (*p)->curset->active_currency->numerical_value == 0 || (*p)->curset->currency_changed == 1 ) {
+            (*p)->curset->inc_dec_status = 0;
+        }
+        else if ( value > (*p)->curset->active_currency->numerical_value ) {
+            printf("%lf-%lf\n", value, (*p)->curset->active_currency->numerical_value );
+            (*p)->curset->inc_dec_status = 1;
+        }
+        else if ( value < (*p)->curset->active_currency->numerical_value ) {
+            (*p)->curset->inc_dec_status = -1;
+        }
        
         (*p)->curset->not_updated = 0;
+        (*p)->curset->active_currency->numerical_value = value;
         strcpy((*p)->curset->active_currency->name, currencies[(*p)->curset->active_currency->type - 1]);
         strcpy((*p)->curset->name, currencies[(*p)->curset->type - 1]);
         strncpy((*p)->curset->active_currency->value, st, 20);
